@@ -18,7 +18,8 @@ from chaoslib.types import (
 )
 from logzero import logger
 
-__version__ = "0.23.1"
+from .__version__ import __version__
+
 __all__ = ["get_session", "discover", "parse_duration"]
 RELIABLY_HOST = "app.reliably.com"
 
@@ -109,6 +110,12 @@ def load_exported_activities() -> List[DiscoveredActivities]:
     activities.extend(discover_probes("chaosreliably.activities.gh.probes"))
     activities.extend(discover_probes("chaosreliably.activities.load.probes"))
     activities.extend(discover_actions("chaosreliably.activities.load.actions"))
+    activities.extend(discover_probes("chaosreliably.activities.slo.probes"))
+    activities.extend(
+        discover_activities(
+            "chaosreliably.activities.slo.tolerances", "tolerance"
+        )
+    )
 
     return activities
 
