@@ -7,7 +7,7 @@ import time
 from copy import deepcopy
 from datetime import datetime, timezone
 from logging import Formatter, StreamHandler
-from typing import Any, Dict, List, Optional, cast
+from typing import Any, Dict, Optional, cast
 
 from chaoslib.exit import exit_gracefully, exit_ungracefully
 from chaoslib.run import EventHandlerRegistry, RunEventHandler
@@ -44,7 +44,7 @@ class ReliablyHandler(RunEventHandler):  # type: ignore
         self.started = datetime.utcnow().replace(tzinfo=timezone.utc)
         self.experiment = deepcopy(experiment)
         self.journal = None  # type: Journal
-        self.current_activities = []  # type: List[Activity]
+        self.current_activities = []  # type: ignore
 
         self.should_stop = threading.Event()
         self.should_pause = threading.Event()
@@ -594,6 +594,8 @@ def set_plan_status(
     if not plan_id:
         return None
 
+    logger.debug(f"Sending plan '{plan_id}' status: {status}")
+
     with get_session(configuration, secrets) as session:
         r = session.put(
             f"/{org_id}/plans/{plan_id}/status",
@@ -616,6 +618,8 @@ def set_execution_state(
     if not exec_id:
         return None
 
+    state["plan_id"] = os.getenv("RELIABLY_PLAN_ID")
+
     with get_session(configuration, secrets) as session:
         r = session.put(
             f"/{org_id}/experiments/{exp_id}/executions/{exec_id}/state",
